# 14 "src/why3doc/doc_lexer.mll"
 

  open Format
  open Lexing
  open Why3

  let output_comments = ref true

  let newline lexbuf =
    let pos = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <-
      { pos with pos_lnum = pos.pos_lnum + 1; pos_bol = pos.pos_cnum }

  let make_table l =
    let ht = Hashtbl.create 97 in
    List.iter (fun s -> Hashtbl.add ht s ()) l;
    Hashtbl.mem ht

  let is_keyword1 = make_table [ "as"; "axiom"; "clone"; "coinductive";
    "constant"; "else"; "end"; "epsilon"; "exists"; "export"; "false";
    "forall"; "function"; "goal"; "if"; "import"; "in"; "inductive";
    "lemma"; "let"; "match"; "meta"; "namespace"; "not"; "predicate";
    "prop"; "then"; "theory"; "true"; "type"; "use"; "with";
    (* programs *) "abstract"; "any";
    "begin"; "do"; "done"; "downto"; "exception";
    "for"; "fun"; "ghost"; "loop"; "model"; "module";
    "mutable"; "private"; "raise"; "rec";
    "to"; "try"; "val"; "while"; ]

  let is_keyword2 = make_table [ "absurd"; "assert"; "assume";
    "ensures"; "check"; "invariant"; "raises"; "reads"; "requires";
    "returns"; "variant"; "writes"; "diverges"; ]

  let get_loc lb =
    Loc.extract (Lexing.lexeme_start_p lb, Lexing.lexeme_end_p lb)

  let html_char fmt c =
    pp_print_string fmt (match c with
      | '<' -> "&lt;"
      | '>' -> "&gt;"
      | '&' -> "&amp;"
      | _ -> assert false)

  let html_escape s =
    let len = ref 0 in
    String.iter (function '<' | '>' -> len := !len + 4
      | '&' -> len := !len + 5 | _ -> incr len) s;
    let len' = !len in
    let len = String.length s in
    if len = len' then s else begin
      let t = String.create len' in
      let j = ref 0 in
      let app u =
        let l = String.length u in
        String.blit u 0 t !j l;
        j := !j + l in
      for i = 0 to len - 1 do
        match s.[i] with
        | '<' -> app "&lt;"
        | '>' -> app "&gt;"
        | '&' -> app "&amp;"
        | c -> t.[!j] <- c; incr j
      done;
      t
    end

  let current_file = ref ""

  let print_ident fmt lexbuf s =
    if is_keyword1 s then
      fprintf fmt "<span class=\"keyword1\">%s</span>" s
    else if is_keyword2 s then
      fprintf fmt "<span class=\"keyword2\">%s</span>" s
    else begin
      let (* f,l,c as *) loc = get_loc lexbuf in
      (* Format.eprintf "  IDENT %s/%d/%d@." f l c; *)
      (* is this a def point? *)
      let s = html_escape s in
      try
        match Glob.find loc with
        | id, Glob.Def ->
          let t = Doc_def.anchor id in
          fprintf fmt "<a name=\"%s\">%s</a>" t s
        | id, Glob.Use ->
          let url = Doc_def.locate id in
          fprintf fmt "<a href=\"%s\">%s</a>" url s
      with Not_found ->
        (* otherwise, just print it *)
        pp_print_string fmt s
    end

  type empty_line = PrevEmpty | CurrEmpty | NotEmpty


# 97 "src/why3doc/doc_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\246\255\007\000\247\255\248\255\032\000\094\000\133\000\
    \179\000\225\000\008\001\070\001\250\255\012\000\006\000\008\000\
    \012\000\255\255\252\255\254\255\009\000\133\000\013\000\014\000\
    \249\255\012\000\033\000\014\000\003\000\084\000\183\001\249\255\
    \094\000\250\255\251\255\019\002\058\002\104\002\143\002\189\002\
    \222\002\253\255\254\255\074\000\088\000\075\000\093\000\252\255\
    \051\000\106\000\050\001\249\255\112\000\250\255\251\255\252\255\
    \253\255\106\000\106\000\255\255\254\255\110\000\071\001\252\255\
    \008\000\253\255\254\255\255\255\096\002\244\255\245\255\247\255\
    \248\255\132\000\191\000\254\255\109\000\119\000\112\000\130\000\
    \255\255\253\255\197\000\250\255\127\000\198\000\251\255\252\255\
    \253\255\254\255\255\255\237\000\252\255\254\255\155\000\118\000\
    \121\000\181\000\181\000\052\000\255\255\162\000\252\255\253\255\
    \132\000\151\000\255\255\254\255";
  Lexing.lex_backtrk = 
   "\255\255\255\255\009\000\255\255\255\255\009\000\006\000\006\000\
    \006\000\006\000\006\000\006\000\255\255\009\000\009\000\004\000\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\002\000\
    \255\255\255\255\006\000\255\255\255\255\255\255\255\255\255\255\
    \006\000\255\255\255\255\003\000\003\000\003\000\003\000\003\000\
    \003\000\255\255\255\255\000\000\255\255\003\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\006\000\255\255\255\255\255\255\
    \255\255\006\000\006\000\255\255\255\255\255\255\255\255\255\255\
    \003\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\006\000\003\000\255\255\011\000\009\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\004\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\001\000\003\000\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \003\000\003\000\255\255\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\255\255\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\000\000\000\000\000\000\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\255\255\031\000\000\000\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\051\000\000\000\255\255\000\000\000\000\000\000\
    \000\000\255\255\255\255\000\000\000\000\255\255\063\000\000\000\
    \063\000\000\000\000\000\000\000\069\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \000\000\000\000\255\255\000\000\255\255\086\000\000\000\000\000\
    \000\000\000\000\000\000\092\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\099\000\000\000\102\000\000\000\000\000\
    \255\255\255\255\000\000\000\000";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\013\000\004\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\021\000\004\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \013\000\010\000\003\000\006\000\006\000\007\000\006\000\002\000\
    \014\000\029\000\007\000\008\000\021\000\008\000\006\000\007\000\
    \015\000\017\000\016\000\022\000\020\000\018\000\019\000\023\000\
    \019\000\028\000\006\000\024\000\009\000\009\000\009\000\010\000\
    \006\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\005\000\025\000\027\000\006\000\011\000\
    \024\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\001\000\006\000\026\000\009\000\006\000\
    \049\000\006\000\006\000\007\000\006\000\048\000\044\000\046\000\
    \007\000\008\000\047\000\008\000\006\000\007\000\021\000\004\000\
    \047\000\031\000\061\000\060\000\059\000\051\000\080\000\079\000\
    \006\000\080\000\009\000\009\000\009\000\006\000\006\000\084\000\
    \096\000\078\000\079\000\097\000\094\000\021\000\007\000\045\000\
    \007\000\007\000\007\000\007\000\078\000\020\000\107\000\007\000\
    \008\000\100\000\008\000\007\000\007\000\084\000\084\000\084\000\
    \084\000\084\000\084\000\094\000\006\000\024\000\097\000\007\000\
    \106\000\009\000\009\000\009\000\007\000\007\000\000\000\000\000\
    \082\000\081\000\104\000\000\000\105\000\000\000\082\000\081\000\
    \089\000\000\000\000\000\000\000\008\000\097\000\008\000\008\000\
    \008\000\008\000\006\000\000\000\009\000\008\000\008\000\082\000\
    \008\000\008\000\008\000\007\000\024\000\082\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\083\000\008\000\000\000\009\000\
    \009\000\009\000\008\000\008\000\000\000\000\000\094\000\093\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \012\000\007\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \255\255\000\000\000\000\009\000\009\000\094\000\009\000\009\000\
    \009\000\008\000\024\000\000\000\000\000\095\000\000\000\000\000\
    \000\000\000\000\000\000\009\000\000\000\009\000\009\000\009\000\
    \009\000\009\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\010\000\000\000\010\000\010\000\007\000\010\000\008\000\
    \098\000\009\000\007\000\008\000\255\255\008\000\010\000\007\000\
    \000\000\000\000\000\000\000\000\055\000\000\000\000\000\009\000\
    \024\000\088\000\010\000\087\000\009\000\009\000\009\000\010\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\067\000\000\000\000\000\054\000\000\000\000\000\000\000\
    \053\000\052\000\058\000\000\000\057\000\009\000\000\000\009\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\010\000\024\000\
    \000\000\066\000\000\000\000\000\000\000\065\000\053\000\000\000\
    \053\000\000\000\000\000\000\000\000\000\000\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \000\000\000\000\000\000\065\000\010\000\065\000\009\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\000\000\103\000\064\000\000\000\011\000\000\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\034\000\000\000\000\000\000\000\000\000\090\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \039\000\033\000\035\000\035\000\036\000\035\000\032\000\000\000\
    \000\000\036\000\037\000\000\000\037\000\035\000\036\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\035\000\000\000\038\000\038\000\038\000\039\000\035\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\043\000\000\000\042\000\035\000\040\000\000\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\056\000\035\000\035\000\038\000\035\000\035\000\
    \036\000\035\000\000\000\000\000\000\000\036\000\037\000\000\000\
    \037\000\035\000\036\000\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\035\000\000\000\038\000\
    \038\000\038\000\035\000\035\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\036\000\000\000\036\000\036\000\036\000\
    \036\000\000\000\000\000\000\000\036\000\037\000\000\000\037\000\
    \036\000\036\000\074\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\035\000\047\000\000\000\036\000\000\000\038\000\038\000\
    \038\000\036\000\036\000\000\000\000\000\000\000\000\000\000\000\
    \077\000\000\000\000\000\000\000\000\000\000\000\070\000\000\000\
    \000\000\037\000\076\000\037\000\037\000\037\000\037\000\035\000\
    \000\000\038\000\037\000\037\000\000\000\037\000\037\000\037\000\
    \036\000\047\000\000\000\000\000\070\000\000\000\070\000\000\000\
    \000\000\000\000\037\000\000\000\038\000\038\000\038\000\037\000\
    \037\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \038\000\000\000\038\000\038\000\038\000\038\000\036\000\041\000\
    \038\000\038\000\038\000\071\000\038\000\038\000\038\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\037\000\047\000\
    \000\000\038\000\000\000\038\000\038\000\038\000\038\000\038\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\073\000\000\000\072\000\039\000\000\000\
    \039\000\039\000\036\000\039\000\037\000\000\000\038\000\036\000\
    \037\000\000\000\037\000\039\000\036\000\038\000\047\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\039\000\
    \000\000\038\000\038\000\038\000\039\000\039\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\038\000\000\000\038\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \000\000\000\000\000\000\039\000\047\000\000\000\000\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\039\000\000\000\038\000\000\000\040\000\000\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \075\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\013\000\013\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\002\000\000\000\000\000\013\000\000\000\000\000\000\000\
    \014\000\015\000\015\000\020\000\013\000\016\000\016\000\022\000\
    \023\000\025\000\000\000\027\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\005\000\026\000\000\000\000\000\
    \028\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\029\000\000\000\005\000\000\000\006\000\
    \032\000\006\000\006\000\006\000\006\000\044\000\043\000\045\000\
    \006\000\006\000\046\000\006\000\006\000\006\000\021\000\021\000\
    \048\000\049\000\052\000\057\000\058\000\061\000\076\000\077\000\
    \006\000\078\000\006\000\006\000\006\000\006\000\006\000\084\000\
    \095\000\077\000\079\000\096\000\094\000\021\000\007\000\043\000\
    \007\000\007\000\007\000\007\000\079\000\021\000\104\000\007\000\
    \007\000\099\000\007\000\007\000\007\000\073\000\073\000\073\000\
    \073\000\073\000\073\000\094\000\006\000\006\000\097\000\007\000\
    \105\000\007\000\007\000\007\000\007\000\007\000\255\255\255\255\
    \074\000\074\000\101\000\255\255\101\000\255\255\082\000\082\000\
    \085\000\255\255\255\255\255\255\008\000\097\000\008\000\008\000\
    \008\000\008\000\006\000\255\255\006\000\008\000\008\000\074\000\
    \008\000\008\000\008\000\007\000\007\000\082\000\098\000\098\000\
    \098\000\098\000\098\000\098\000\073\000\008\000\255\255\008\000\
    \008\000\008\000\008\000\008\000\255\255\255\255\091\000\091\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\007\000\009\000\007\000\009\000\009\000\009\000\009\000\
    \064\000\255\255\255\255\009\000\009\000\091\000\009\000\009\000\
    \009\000\008\000\008\000\255\255\255\255\091\000\255\255\255\255\
    \255\255\255\255\255\255\009\000\255\255\009\000\009\000\009\000\
    \009\000\009\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\010\000\255\255\010\000\010\000\010\000\010\000\008\000\
    \097\000\008\000\010\000\010\000\099\000\010\000\010\000\010\000\
    \255\255\255\255\255\255\255\255\050\000\255\255\255\255\009\000\
    \009\000\085\000\010\000\085\000\010\000\010\000\010\000\010\000\
    \010\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\062\000\255\255\255\255\050\000\255\255\255\255\255\255\
    \050\000\050\000\050\000\255\255\050\000\009\000\255\255\009\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\010\000\010\000\
    \255\255\062\000\255\255\255\255\255\255\062\000\050\000\255\255\
    \050\000\255\255\255\255\255\255\255\255\255\255\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \255\255\255\255\255\255\062\000\010\000\062\000\010\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\255\255\101\000\062\000\255\255\011\000\255\255\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\030\000\255\255\255\255\255\255\255\255\085\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\255\255\
    \255\255\030\000\030\000\255\255\030\000\030\000\030\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\030\000\255\255\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\255\255\030\000\030\000\030\000\255\255\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\030\000\030\000\030\000\030\000\030\000\030\000\
    \030\000\030\000\050\000\030\000\035\000\030\000\035\000\035\000\
    \035\000\035\000\255\255\255\255\255\255\035\000\035\000\255\255\
    \035\000\035\000\035\000\255\255\255\255\255\255\255\255\062\000\
    \255\255\255\255\255\255\255\255\255\255\035\000\255\255\035\000\
    \035\000\035\000\035\000\035\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\036\000\255\255\036\000\036\000\036\000\
    \036\000\255\255\255\255\255\255\036\000\036\000\255\255\036\000\
    \036\000\036\000\068\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\035\000\035\000\255\255\036\000\255\255\036\000\036\000\
    \036\000\036\000\036\000\255\255\255\255\255\255\255\255\255\255\
    \068\000\255\255\255\255\255\255\255\255\255\255\068\000\255\255\
    \255\255\037\000\068\000\037\000\037\000\037\000\037\000\035\000\
    \255\255\035\000\037\000\037\000\255\255\037\000\037\000\037\000\
    \036\000\036\000\255\255\255\255\068\000\255\255\068\000\255\255\
    \255\255\255\255\037\000\255\255\037\000\037\000\037\000\037\000\
    \037\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \038\000\255\255\038\000\038\000\038\000\038\000\036\000\030\000\
    \036\000\038\000\038\000\068\000\038\000\038\000\038\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\037\000\037\000\
    \255\255\038\000\255\255\038\000\038\000\038\000\038\000\038\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\068\000\255\255\068\000\039\000\255\255\
    \039\000\039\000\039\000\039\000\037\000\255\255\037\000\039\000\
    \039\000\255\255\039\000\039\000\039\000\038\000\038\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\039\000\
    \255\255\039\000\039\000\039\000\039\000\039\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\038\000\255\255\038\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \255\255\255\255\255\255\039\000\039\000\255\255\255\255\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\039\000\255\255\039\000\255\255\040\000\255\255\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
    \040\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \068\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\004\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\001\000\001\000\001\000\001\000\001\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\098\000\098\000\098\000\098\000\098\000\098\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_code = 
   "\255\001\255\255\000\001\255";
}

let rec scan fmt empty lexbuf =
    __ocaml_lex_scan_rec fmt empty lexbuf 0
and __ocaml_lex_scan_rec fmt empty lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 135 "src/why3doc/doc_lexer.mll"
             s
# 519 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 3) in
# 136 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt s;
            scan fmt NotEmpty lexbuf )
# 524 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 139 "src/why3doc/doc_lexer.mll"
          ( comment fmt false lexbuf;
            scan fmt empty lexbuf )
# 530 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 142 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "</pre>\n";
            if empty <> PrevEmpty then
              pp_print_string fmt "<div class=\"info\">";
            doc fmt false [] lexbuf;
            if empty <> PrevEmpty then pp_print_string fmt "</div>";
            pp_print_string fmt "<pre>";
            scan fmt CurrEmpty lexbuf )
# 541 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 150 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "<span class=\"comment\">(**)</span>";
            scan fmt NotEmpty lexbuf )
# 547 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 153 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "<span class=\"comment\">(*";
            comment fmt true lexbuf;
            pp_print_string fmt "</span>";
            scan fmt NotEmpty lexbuf )
# 555 "src/why3doc/doc_lexer.ml"

  | 5 ->
# 157 "src/why3doc/doc_lexer.mll"
          ( () )
# 560 "src/why3doc/doc_lexer.ml"

  | 6 ->
let
# 158 "src/why3doc/doc_lexer.mll"
             s
# 566 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 159 "src/why3doc/doc_lexer.mll"
          ( print_ident fmt lexbuf s;
            scan fmt NotEmpty lexbuf )
# 571 "src/why3doc/doc_lexer.ml"

  | 7 ->
# 162 "src/why3doc/doc_lexer.mll"
          ( newline lexbuf;
            if empty <> PrevEmpty then pp_print_char fmt '\n';
            let e = if empty = NotEmpty then CurrEmpty else PrevEmpty in
            scan fmt e lexbuf )
# 579 "src/why3doc/doc_lexer.ml"

  | 8 ->
# 166 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "&quot;";
            string fmt true lexbuf;
            scan fmt NotEmpty lexbuf )
# 586 "src/why3doc/doc_lexer.ml"

  | 9 ->
let
# 170 "src/why3doc/doc_lexer.mll"
         s
# 592 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 171 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt s;
            scan fmt NotEmpty lexbuf )
# 597 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_scan_rec fmt empty lexbuf __ocaml_lex_state

and scan_embedded fmt depth lexbuf =
    __ocaml_lex_scan_embedded_rec fmt depth lexbuf 30
and __ocaml_lex_scan_embedded_rec fmt depth lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 175 "src/why3doc/doc_lexer.mll"
          ( pp_print_char fmt '[';
            scan_embedded fmt (depth + 1) lexbuf )
# 609 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 177 "src/why3doc/doc_lexer.mll"
          ( if depth > 0 then begin
              pp_print_char fmt ']';
              scan_embedded fmt (depth - 1) lexbuf
            end )
# 617 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 181 "src/why3doc/doc_lexer.mll"
          ( () )
# 622 "src/why3doc/doc_lexer.ml"

  | 3 ->
let
# 182 "src/why3doc/doc_lexer.mll"
             s
# 628 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 183 "src/why3doc/doc_lexer.mll"
          ( print_ident fmt lexbuf s;
            scan_embedded fmt depth lexbuf )
# 633 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 185 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             scan_embedded fmt depth lexbuf )
# 640 "src/why3doc/doc_lexer.ml"

  | 5 ->
# 188 "src/why3doc/doc_lexer.mll"
           ( pp_print_string fmt "&quot;";
             string fmt true lexbuf;
             scan_embedded fmt depth lexbuf )
# 647 "src/why3doc/doc_lexer.ml"

  | 6 ->
let
# 192 "src/why3doc/doc_lexer.mll"
         s
# 653 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 192 "src/why3doc/doc_lexer.mll"
           ( pp_print_string fmt s;
             scan_embedded fmt depth lexbuf )
# 658 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_scan_embedded_rec fmt depth lexbuf __ocaml_lex_state

and comment fmt do_output lexbuf =
    __ocaml_lex_comment_rec fmt do_output lexbuf 50
and __ocaml_lex_comment_rec fmt do_output lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 196 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "(*";
             comment fmt do_output lexbuf;
             comment fmt do_output lexbuf )
# 671 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 199 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "*)" )
# 676 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 200 "src/why3doc/doc_lexer.mll"
           ( () )
# 681 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 201 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             if do_output then pp_print_char fmt '\n';
             comment fmt do_output lexbuf )
# 688 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 204 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "&quot;";
             string fmt do_output lexbuf;
             comment fmt do_output lexbuf )
# 695 "src/why3doc/doc_lexer.ml"

  | 5 ->
let
# 207 "src/why3doc/doc_lexer.mll"
               c
# 701 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 208 "src/why3doc/doc_lexer.mll"
           ( if do_output then html_char fmt c;
             comment fmt do_output lexbuf )
# 706 "src/why3doc/doc_lexer.ml"

  | 6 ->
let
# 211 "src/why3doc/doc_lexer.mll"
         s
# 712 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 211 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt s;
             comment fmt do_output lexbuf )
# 717 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec fmt do_output lexbuf __ocaml_lex_state

and string fmt do_output lexbuf =
    __ocaml_lex_string_rec fmt do_output lexbuf 62
and __ocaml_lex_string_rec fmt do_output lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 215 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             if do_output then pp_print_char fmt '\n';
             string fmt do_output lexbuf )
# 730 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 218 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "&quot;" )
# 735 "src/why3doc/doc_lexer.ml"

  | 2 ->
let
# 219 "src/why3doc/doc_lexer.mll"
               c
# 741 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 220 "src/why3doc/doc_lexer.mll"
           ( if do_output then html_char fmt c;
             string fmt do_output lexbuf )
# 746 "src/why3doc/doc_lexer.ml"

  | 3 ->
let
# 223 "src/why3doc/doc_lexer.mll"
         s
# 752 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 223 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt s;
             string fmt do_output lexbuf )
# 757 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_string_rec fmt do_output lexbuf __ocaml_lex_state

and doc fmt block headings lexbuf =
    __ocaml_lex_doc_rec fmt block headings lexbuf 68
and __ocaml_lex_doc_rec fmt block headings lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 228 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_string fmt "</p>\n" )
# 768 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 229 "src/why3doc/doc_lexer.mll"
           ( () )
# 773 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 230 "src/why3doc/doc_lexer.mll"
                     ( newline lexbuf;
             newline lexbuf;
             if block then pp_print_string fmt "</p>";
             pp_print_char fmt '\n';
             doc fmt false headings lexbuf )
# 782 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 235 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             doc fmt block headings lexbuf )
# 789 "src/why3doc/doc_lexer.ml"

  | 4 ->
let
# 238 "src/why3doc/doc_lexer.mll"
                      c
# 795 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1) in
# 239 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_string fmt "</p>\n";
             let n = Char.code c - Char.code '0' in
             fprintf fmt "<h%d>" n;
             doc fmt true (n::headings) lexbuf )
# 802 "src/why3doc/doc_lexer.ml"

  | 5 ->
# 243 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             raw_html fmt 0 lexbuf; doc fmt true headings lexbuf )
# 808 "src/why3doc/doc_lexer.ml"

  | 6 ->
# 245 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_char fmt '{';
             doc fmt true (0::headings) lexbuf )
# 815 "src/why3doc/doc_lexer.ml"

  | 7 ->
# 248 "src/why3doc/doc_lexer.mll"
           ( let brace r =
               if not block then pp_print_string fmt "<p>";
               pp_print_char fmt '}';
               doc fmt true r lexbuf
             in
             match headings with
              | [] -> brace headings
              | n :: r ->
                if n >= 1 then begin
                  fprintf fmt "</h%d>" n;
                  doc fmt (r <> []) r lexbuf
                end else brace r
           )
# 832 "src/why3doc/doc_lexer.ml"

  | 8 ->
# 261 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_string fmt "<code>";
             scan_embedded fmt 0 lexbuf;
             pp_print_string fmt "</code>";
             doc fmt true headings lexbuf )
# 841 "src/why3doc/doc_lexer.ml"

  | 9 ->
# 266 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_char fmt ' ';
             doc fmt block headings lexbuf )
# 847 "src/why3doc/doc_lexer.ml"

  | 10 ->
let
# 268 "src/why3doc/doc_lexer.mll"
               c
# 853 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 269 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             html_char fmt c;
             doc fmt true headings lexbuf )
# 859 "src/why3doc/doc_lexer.ml"

  | 11 ->
let
# 272 "src/why3doc/doc_lexer.mll"
         c
# 865 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 272 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_char fmt c;
             doc fmt true headings lexbuf )
# 871 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_doc_rec fmt block headings lexbuf __ocaml_lex_state

and raw_html fmt depth lexbuf =
    __ocaml_lex_raw_html_rec fmt depth lexbuf 85
and __ocaml_lex_raw_html_rec fmt depth lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 278 "src/why3doc/doc_lexer.mll"
           ( () )
# 882 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 279 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             raw_html fmt depth lexbuf )
# 889 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 282 "src/why3doc/doc_lexer.mll"
           ( pp_print_char fmt '{'; raw_html fmt (succ depth) lexbuf )
# 894 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 283 "src/why3doc/doc_lexer.mll"
           ( if depth = 0 then () else
               begin
                 pp_print_char fmt '}';
                 raw_html fmt (pred depth) lexbuf
               end )
# 903 "src/why3doc/doc_lexer.ml"

  | 4 ->
let
# 288 "src/why3doc/doc_lexer.mll"
         c
# 909 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 288 "src/why3doc/doc_lexer.mll"
           ( pp_print_char fmt c; raw_html fmt depth lexbuf )
# 913 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_raw_html_rec fmt depth lexbuf __ocaml_lex_state

and extract_header lexbuf =
  lexbuf.Lexing.lex_mem <- Array.create 2 (-1) ;   __ocaml_lex_extract_header_rec lexbuf 91
and __ocaml_lex_extract_header_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 292 "src/why3doc/doc_lexer.mll"
                                            header
# 925 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 293 "src/why3doc/doc_lexer.mll"
      ( header )
# 929 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 295 "src/why3doc/doc_lexer.mll"
      ( extract_header lexbuf )
# 934 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 297 "src/why3doc/doc_lexer.mll"
      ( skip_comment lexbuf; extract_header lexbuf )
# 939 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 299 "src/why3doc/doc_lexer.mll"
      ( "" )
# 944 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_extract_header_rec lexbuf __ocaml_lex_state

and skip_comment lexbuf =
    __ocaml_lex_skip_comment_rec lexbuf 101
and __ocaml_lex_skip_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 302 "src/why3doc/doc_lexer.mll"
         ( () )
# 955 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 303 "src/why3doc/doc_lexer.mll"
         ( skip_comment lexbuf; skip_comment lexbuf )
# 960 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 304 "src/why3doc/doc_lexer.mll"
         ( () )
# 965 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 305 "src/why3doc/doc_lexer.mll"
         ( skip_comment lexbuf )
# 970 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_skip_comment_rec lexbuf __ocaml_lex_state

;;

# 307 "src/why3doc/doc_lexer.mll"
 

  let do_file fmt fname =
    current_file := fname;
    (* input *)
    let cin = open_in fname in
    let lb = Lexing.from_channel cin in
    lb.Lexing.lex_curr_p <-
      { lb.Lexing.lex_curr_p with Lexing.pos_fname = fname };
    (* output *)
    pp_print_string fmt "<div class=\"why3doc\">\n<pre>";
    scan fmt PrevEmpty lb;
    pp_print_string fmt "</pre>\n</div>\n";
    close_in cin

  let extract_header fname =
    let cin = open_in fname in
    let lb = Lexing.from_channel cin in
    let h = extract_header lb in
    close_in cin;
    h


# 1000 "src/why3doc/doc_lexer.ml"
